function [alpha,beta,gamma] = gg303_lab2_template(pole_trend,pole_plunge)
% function [alpha,beta,gamma] = gg303_lab2_template(pole_trend,pole_plunge)
% Returns the direction cosines (i.e., Cartesian coordinates) of a pole of
% unit length.
%
% Input arguments
% pole_trend = trend of pole (in degrees)
% pole_plunge = plunge of pole (in degrees)
% Output arguments
% alpha = direction cosine of pole relative to x-axis (north)
% beta = direction cosine of pole relative to y-axis (east)
% gamma = direction cosine of pole relative to z-axis (down)
%
% Example
% [alpha,beta,gamma] = GG303_lab2_template(20,30)

% Convert the pole trend and pole plunge from degrees to radians
% Use either the Matlab function radtodeg or a conversion factor of pi/180
% INSERT LINE(S) OF CODE HERE

% Convert the trend and plunge (in radians) of a pole of unit length 
% (i.e., the three spherical coordinates) 
% to direction cosines (i.e., Cartesian coordinates) 
% using Matlab's sph2cart function (see the Matlab help page)
% INSERT LINE(S) OF CODE HERE

end

